import { Dialog, DialogActions, DialogContent, DialogTitle, Box } from "@mui/material";
import React, { useState, useRef, useEffect, useMemo } from "react";
import {
    List,
    DatagridConfigurable,
    SearchInput,
    TopToolbar,
    Button,
    SelectColumnsButton,
    EditButton,
    FilterButton,
    CreateButton,
    ExportButton,
    BulkDeleteButton,
    WrapperField,
    Toolbar,
    useRecordContext,
    useTranslate,
    useNotify,
    useListContext,
    FunctionField,
    TextField,
    NumberField,
    DateField,
    BooleanField,
    ReferenceField,
    TextInput,
    DateTimeInput,
    DateInput,
    SelectInput,
    NumberInput,
    ReferenceInput,
    ReferenceArrayInput,
    AutocompleteInput,
    DeleteButton,
    Form,
    SaveButton,
    useRefresh,
} from 'react-admin';
import DialogCloseButton from "../../components/DialogCloseButton";
import { styled } from '@mui/material/styles';
import { PAGE_DRAWER_WIDTH, OPERATE_MODE, DEFAULT_PAGE_SIZE } from '@/config/setting';
import { Grid, Stack } from "@mui/system";
import SaveIcon from '@mui/icons-material/Save';


const StyledDatagrid = styled(DatagridConfigurable)(({ theme }) => ({
    '& .css-1vooibu-MuiSvgIcon-root': {
        height: '.9em'
    },
    '& .RaDatagrid-row': {
        cursor: 'auto'
    },
    '& .column-name': {
    },
    '& .opt': {
        width: 220
    },
    '& .wkType': {
        width: 110
    },
    '& .status': {
        width: 90
    },
}));
const filters = [
    <SearchInput source="condition" alwaysOn />,
    <DateInput label='common.time.after' source="timeStart" />,
    <DateInput label='common.time.before' source="timeEnd" />,
    <TextInput source="code" label="table.field.delivery.code" />,
    <TextInput source="platId" label="table.field.delivery.platId" />,
    <TextInput source="type" label="table.field.delivery.type" />,
    <TextInput source="wkType" label="table.field.delivery.wkType" />,
    <TextInput source="source" label="table.field.delivery.source" />,
    <SelectInput
        label="common.field.status"
        source="status"
        choices={[
            { id: '1', name: 'common.enums.statusTrue' },
            { id: '0', name: 'common.enums.statusFalse' },
        ]}
        resettable
    />,
]

const OutOrderModal = (props) => {
    const { open, setOpen, record } = props;
    const translate = useTranslate();
    const [params, setParams] = useState({});
    const [drawerVal, setDrawerVal] = useState(false);
    const refresh = useRefresh();

    const handleClose = (event, reason) => {
        if (reason !== "backdropClick") {
            setOpen(false);
        }
    };
    return (
        <Dialog
            open={open}
            onClose={handleClose}
            aria-labelledby="form-dialog-title"
            aria-hidden
            fullWidth
            disableRestoreFocus
            maxWidth="lg"
        >
            <DialogTitle id="form-dialog-title" sx={{
                position: 'sticky',
                top: 0,
                backgroundColor: 'background.paper',
                zIndex: 1000
            }}>
                {translate('create.title')}
                <Box sx={{ position: 'absolute', top: 8, right: 8, zIndex: 1001 }}>
                    <DialogCloseButton onClose={handleClose} />
                </Box>
            </DialogTitle>
            <Grid container rowSpacing={2} columnSpacing={2}>
                <DialogContent>
                    <Grid item sx={24}>
                        <List
                            resource="deliveryItem"
                            sx={{
                                flexGrow: 1,
                                transition: (theme) =>
                                    theme.transitions.create(['all'], {
                                        duration: theme.transitions.duration.enteringScreen,
                                    }),
                                marginRight: drawerVal ? `${PAGE_DRAWER_WIDTH}px` : 0,
                            }}
                            storeKey='selectDelivery'
                            queryOptions={params}
                            filters={<CustomFilter />}
                            empty={false}
                            sort={{ field: "create_time", order: "desc" }}
                            actions={(
                                <TopToolbar>
                                    <></>
                                </TopToolbar>
                            )}
                            perPage={DEFAULT_PAGE_SIZE}
                        >
                            <StyledDatagrid
                                preferenceKey='deliveryItem'
                                bulkActionButtons={() => <></>}
                                rowClick={(id, resource, record) => false}
                                expand={false}
                                expandSingle={true}
                                omit={['id', 'createTime', 'createBy', 'memo', 'workQty', 'startTime', 'endTime', 'updateBy', 'createTime']}
                            >
                                <NumberField source="id" />
                                <TextField source="matnrCode" label="table.field.deliveryItem.matnrCode" />
                                <TextField source="matnrName" label="table.field.deliveryItem.matnrName" />
                                <TextField source="unit" label="table.field.deliveryItem.unit" />
                                <NumberField source="anfme" label="table.field.deliveryItem.anfme" />
                                <TextField source="splrName" label="table.field.deliveryItem.splrName" />
                                <TextField source="splrBatch" label="table.field.deliveryItem.splrBatch" />
                                <TextField source="updateBy$" label="common.field.updateBy" />
                                <DateField source="updateTime" label="common.field.updateTime" showTime />
                                <TextField source="createBy$" label="common.field.createBy" />
                                <DateField source="createTime" label="common.field.createTime" showTime />
                                <BooleanField source="statusBool" label="common.field.status" sortable={false} />
                                <TextField source="memo" label="common.field.memo" sortable={false} />
                            </StyledDatagrid>
                        </List>
                    </Grid>
                </DialogContent>
            </Grid>
        </Dialog >
    )
}

export default OutOrderModal;

const CustomFilter = () => {
    const { filterValues, setFilters } = useListContext('deliveryItem');
    const [formValues, setFormValues] = useState(filterValues);

    const handleChange = (event) => {
        setFormValues(formValues => ({
            ...formValues,
            [event.target.name]: event.target.value
        }));
    };

    const handleSubmit = (event) => {
        console.log('---------->');
        console.log(formValues);
        event.preventDefault();
        setFilters(formValues, null, true);
    };

    return (
        <Form>
            <Grid container rowSpacing={2} columnSpacing={2} >
                <Stack>
                    <TextInput
                        source="matnrName"
                        label="table.field.deliveryItem.matnrName"
                        resettable
                        onChange={handleChange}
                        />
                </Stack>
                <Stack>
                    <TextInput
                        source="matnrCode"
                        label="table.field.deliveryItem.matnrCode"
                        resettable
                        onChange={handleChange} />
                </Stack>
                <Stack>
                    <TextInput
                        source="splrName"
                        label="table.field.deliveryItem.splrName"
                        resettable
                        onChange={handleChange} />
                </Stack>
                <Stack>
                    <TextInput
                        source="splrName"
                        label="table.field.deliveryItem.splrName"
                        resettable
                        onChange={handleChange} />
                </Stack>
            </Grid>
            <DialogActions>
                <Toolbar sx={{ width: '100%', justifyContent: 'end' }}  >
                    <SaveButton onClick={handleSubmit}/>
                    {/* <Button variant="contained" label="toolbar.confirm" startIcon={<SaveIcon />} onClick={handleSubmit} /> */}
                </Toolbar>
            </DialogActions>
        </Form>
    );
};
